@@ -7,7 +7,9 @@
 -- Stability   : experimental
 -- Portability : unknown
 --
--- This module is documentation module for relational record.
+-- This module is documentation module for relational-record.
+-- The project page of relational-record is
+-- http://khibino.github.io/haskell-relational-record/ .
 module Database.Relational.Query.Documentation (
   -- * Concepts
   -- $concepts
@@ -158,6 +160,7 @@ module Database.Relational.Query.Documentation (
   prepareQuery,
   fetch,
   runQuery,
+  runQuery',
 
   -- ** Insert Values
   -- $insertValue
@@ -378,6 +381,9 @@ Actions to manage generalized SQL statements.
 
 {- $select
 Actions to manage SELECT statements.
+
+'runQuery' function is lazy-read and 'runQuery'' function is strict version,
+please use carefully.
  -}
 
 {- $insertValue
